@@ -15,7 +15,7 @@ our @EXPORT_OK = (
 );
 our %EXPORT_TAGS = (all => \@EXPORT_OK);
 
-our $VERSION = "v6.7.1";
+our $VERSION = "v6.7.2";
 
 1;
 __END__
@@ -475,11 +475,24 @@ L<https://rxjs.dev/api/operators/filter>
 
 L<https://rxjs.dev/api/operators/finalize>
 
+I<< Note: >> Observe, in the second example below, that the order of execution of
+the finalize callbacks obeys the rxjs v7 order ('f1' first) rather than the rxjs v6
+order ('f2' first).
+
     # 1, 2, 3, complete, 'hi there'
     rx_of(1, 2, 3)->pipe(
-        op_finalize(sub {print "hi there\n"}),
+        op_finalize(sub { say "hi there" }),
     )->subscribe($observer);
 
+    # 0, f1, f2
+    my $s; $s = rx_interval(1)->pipe(
+        op_finalize(sub { say "f1" }),
+        op_finalize(sub { say "f2" }),
+    )->subscribe(sub {
+        say $_[0];
+        $s->unsubscribe;
+    });
+
 =item op_first
 
 L<https://rxjs.dev/api/operators/first>
