@@ -8,7 +8,7 @@ use RxPerl::Utils qw/ get_timer_subs /;
 use RxPerl::Subscription;
 
 use Carp 'croak';
-use Scalar::Util 'reftype', 'refaddr', 'blessed';
+use Scalar::Util 'reftype', 'refaddr', 'blessed', 'weaken';
 
 use Exporter 'import';
 our @EXPORT_OK = qw/
@@ -20,7 +20,7 @@ our @EXPORT_OK = qw/
 /;
 our %EXPORT_TAGS = (all => \@EXPORT_OK);
 
-our $VERSION = "v6.7.1";
+our $VERSION = "v6.7.2";
 
 sub op_audit_time {
     my ($duration) = @_;
@@ -483,25 +483,32 @@ sub op_finalize {
             my ($subscriber) = @_;
 
             my $will_finalize_later = 0;
+            weaken(my $wk_finalize_cbs = $subscriber->{_subscription}{_finalize_cbs} //= []);
+            unshift @$wk_finalize_cbs, $fn;
 
             my $own_subscriber = {
                 %$subscriber,
                 error => sub {
                     $will_finalize_later = 1;
                     $subscriber->{error}->(@_) if defined $subscriber->{error};
-                    $fn->();
+                    $_->() foreach @$wk_finalize_cbs;
+                    undef @$wk_finalize_cbs;
                 },
                 complete => sub {
                     $will_finalize_later = 1;
                     $subscriber->{complete}->() if defined $subscriber->{complete};
-                    $fn->();
+                    $_->() foreach @$wk_finalize_cbs;
+                    undef @$wk_finalize_cbs;
                 },
             };
 
             $source->subscribe($own_subscriber);
 
             return sub {
-                $fn->() unless $will_finalize_later;
+                unless ($will_finalize_later) {
+                    $_->() foreach @$wk_finalize_cbs;
+                    undef @$wk_finalize_cbs;
+                }
             };
         });
     };
